@@ -13,8 +13,8 @@ from plagdef.repositories import UnsupportedFileFormatError
 
 def find_matches(doc_repo, config_repo, common_doc_repo=None) -> set[DocumentPairMatches]:
     try:
-        docs = doc_repo.list()
-        common_docs = common_doc_repo.list() if common_doc_repo else None
+        docs = list(doc_repo.list())
+        common_docs = list(common_doc_repo.list()) if common_doc_repo else None
         config = config_repo.get()
         doc_matcher = DocumentMatcher(config)
         doc_pair_matches = doc_matcher.find_matches(doc_repo.lang, docs, common_docs)
